@@ -2,7 +2,11 @@ import uuid
 
 from django.utils.text import slugify
 
-from .settings import ENABLE_FUZZY_SEARCH, FUZZY_SEARCH_PERCENTAGE
+from .settings import (
+    ENABLE_FUZZY_SEARCH,
+    FUZZY_SEARCH_PERCENTAGE,
+    SEARCH_WORD_BY_WORD_KEYWORDS,
+)
 
 
 if ENABLE_FUZZY_SEARCH:
@@ -28,10 +32,7 @@ def get_answers(query, search_in, draft):
     query = slugify(query)  # replace "AuJoürd'hui" by "aujourd-hui"
 
     if ENABLE_FUZZY_SEARCH:
-        print("fuzzy search")
-        query = slugify(query).replace(
-            "-", " "
-        )  # replace "AuJoürd'hui" by "aujourd hui"
+        query = query.replace("-", " ")  # replace "AuJoürd'hui" by "aujourd hui"
 
     answers_questions = []
     answers_keywords = []
@@ -50,35 +51,60 @@ def get_answers(query, search_in, draft):
         placeholder__page__publisher_is_draft=bool(draft)
     ).filter(parent__id__in=faq_list)
 
-    # get keywords
+    # go through every question in list of selected FAQs
     for question in questions:
-        # str is found in question title
 
+        # search in question title
+        # fuzzy search = handle some user mistakes
         if ENABLE_FUZZY_SEARCH:
-            slug = slugify(question.question).replace("-", " ")
-            # print(query + " - " + slug + " =>", end="")
-            # print((30 - (len(query + " - " + slug))) * " " + str(fuzz.token_sort_ratio(query, slug)))
+            question_str = slugify(question.question).replace("-", " ")
+
+            # debug stuff:
+            # print(query + " - " + question_str + " =>", end="")
+            # print((30 - (len(query + " - " + question_str))) * " " + str(fuzz.token_sort_ratio(query, question_str)))
+
+            # query is the slugified user query
+            # question_str is the slugified question text
             if (
-                fuzz.token_sort_ratio(query, slug)
+                fuzz.token_sort_ratio(query, question_str)
                 >= FUZZY_SEARCH_PERCENTAGE  # see https://github.com/seatgeek/fuzzywuzzy#token-sort-ratio
-            ) or (query in slug):
+            ) or (query in question_str):
                 answers_questions.append(question)
         else:
             if query in slugify(question.question):
                 answers_questions.append(question)
 
-        # str is found in keywords
+        # search in keywords
         for keyword in question.keywords.all():
             if ENABLE_FUZZY_SEARCH:
-                slug = slugify(keyword).replace("-", " ")
-                # print("  " + query + " - " + slug + " =>", end="")
-                # print((28 - (len(query + " - " + slug))) * " " + str(fuzz.token_sort_ratio(query, slug)))
-                if fuzz.token_sort_ratio(query, slug) >= FUZZY_SEARCH_PERCENTAGE:
+                keyword = slugify(keyword).replace("-", " ")
+                # debug stuff
+                # print("  " + query + " - " + keyword + " =>", end="")
+                # print((30 - (len(query + " - " + keyword))) * " " + str(fuzz.token_sort_ratio(query, keyword)))
+
+                # query is the slugified user query
+                # keyword is the slugified keyword
+                if fuzz.token_sort_ratio(query, keyword) >= FUZZY_SEARCH_PERCENTAGE:
                     answers_keywords.append(question)
             else:
                 if query in slugify(keyword):
                     answers_keywords.append(question)
 
+            # search correspondance word by word for each word in query and slugs
+            if SEARCH_WORD_BY_WORD_KEYWORDS:
+                query_list = query.split(" ")
+                for query_word in query_list:
+                    for keyword_word in keyword.split(" "):
+                        if ENABLE_FUZZY_SEARCH:
+                            if (
+                                fuzz.token_sort_ratio(query_word, keyword_word)
+                                >= FUZZY_SEARCH_PERCENTAGE
+                            ):
+                                answers_keywords.append(question)
+                        else:
+                            if query_word == keyword_word:
+                                answers_keywords.append(question)
+
     # all answers
     answers = answers_questions + answers_keywords
 
